pub struct DynStatisticAnalyzerCurrencyGroups(pub Box<dyn StatisticAnalyzerCurrencyGroups + Send + Sync>);Tuple Fields
0: Box<dyn StatisticAnalyzerCurrencyGroups + Send + Sync>Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for DynStatisticAnalyzerCurrencyGroups
impl<'py> IntoPyObject<'py> for DynStatisticAnalyzerCurrencyGroups
Sourcetype Target = DynStatisticAnalyzerCurrencyGroups
type Target = DynStatisticAnalyzerCurrencyGroups
The Python output type
Sourcetype Output = Bound<'py, <DynStatisticAnalyzerCurrencyGroups as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DynStatisticAnalyzerCurrencyGroups as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for DynStatisticAnalyzerCurrencyGroups
impl PyClassImpl for DynStatisticAnalyzerCurrencyGroups
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DynStatisticAnalyzerCurrencyGroups>
type ThreadChecker = SendablePyClass<DynStatisticAnalyzerCurrencyGroups>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<DynStatisticAnalyzerCurrencyGroups> for PyClassImplCollector<DynStatisticAnalyzerCurrencyGroups>
impl PyMethods<DynStatisticAnalyzerCurrencyGroups> for PyClassImplCollector<DynStatisticAnalyzerCurrencyGroups>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyStubType for DynStatisticAnalyzerCurrencyGroups
impl PyStubType for DynStatisticAnalyzerCurrencyGroups
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
Sourcefn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for DynStatisticAnalyzerCurrencyGroups
impl PyTypeInfo for DynStatisticAnalyzerCurrencyGroups
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for DynStatisticAnalyzerCurrencyGroups
impl ExtractPyClassWithClone for DynStatisticAnalyzerCurrencyGroups