pub struct DynStatisticAnalyzerPaths(pub Box<dyn StatisticAnalyzerPaths + Send + Sync>);Tuple Fields
0: Box<dyn StatisticAnalyzerPaths + Send + Sync>Trait Implementations
Sourceimpl Display for DynStatisticAnalyzerPaths
impl Display for DynStatisticAnalyzerPaths
Sourceimpl<'py> IntoPyObject<'py> for DynStatisticAnalyzerPaths
impl<'py> IntoPyObject<'py> for DynStatisticAnalyzerPaths
Sourcetype Target = DynStatisticAnalyzerPaths
type Target = DynStatisticAnalyzerPaths
The Python output type
Sourcetype Output = Bound<'py, <DynStatisticAnalyzerPaths as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DynStatisticAnalyzerPaths as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for DynStatisticAnalyzerPaths
impl PyClass for DynStatisticAnalyzerPaths
Sourceimpl PyClassImpl for DynStatisticAnalyzerPaths
impl PyClassImpl for DynStatisticAnalyzerPaths
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DynStatisticAnalyzerPaths>
type ThreadChecker = SendablePyClass<DynStatisticAnalyzerPaths>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<DynStatisticAnalyzerPaths> for PyClassImplCollector<DynStatisticAnalyzerPaths>
impl PyMethods<DynStatisticAnalyzerPaths> for PyClassImplCollector<DynStatisticAnalyzerPaths>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyStubType for DynStatisticAnalyzerPaths
impl PyStubType for DynStatisticAnalyzerPaths
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
Sourcefn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for DynStatisticAnalyzerPaths
impl PyTypeInfo for DynStatisticAnalyzerPaths
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for DynStatisticAnalyzerPaths
impl ExtractPyClassWithClone for DynStatisticAnalyzerPaths