pub struct StatisticResult {
pub sorted_routes: Vec<ItemRoute>,
pub lower_is_better: bool,
}Fields
sorted_routes: Vec<ItemRoute>lower_is_better: boolTrait Implementations
Sourceimpl Clone for StatisticResult
impl Clone for StatisticResult
Sourcefn clone(&self) -> StatisticResult
fn clone(&self) -> StatisticResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatisticResult
impl Debug for StatisticResult
Sourceimpl<'de> Deserialize<'de> for StatisticResult
impl<'de> Deserialize<'de> for StatisticResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for StatisticResult
impl Display for StatisticResult
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for StatisticResultwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for StatisticResultwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for StatisticResult
impl<'py> IntoPyObject<'py> for StatisticResult
Sourcetype Target = StatisticResult
type Target = StatisticResult
The Python output type
Sourcetype Output = Bound<'py, <StatisticResult as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <StatisticResult as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for StatisticResult
impl PyClass for StatisticResult
Sourceimpl PyClassImpl for StatisticResult
impl PyClassImpl for StatisticResult
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<StatisticResult>
type ThreadChecker = SendablePyClass<StatisticResult>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn weaklist_offset() -> Option<Py_ssize_t>
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
Sourceimpl PyStubType for StatisticResult
impl PyStubType for StatisticResult
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
Sourcefn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for StatisticResult
impl PyTypeInfo for StatisticResult
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
Sourceimpl Serialize for StatisticResult
impl Serialize for StatisticResult
impl DerefToPyAny for StatisticResult