pub struct CraftCurrencyList {
pub list: THashSet<CraftCurrencyEnum>,
}Fields
list: THashSet<CraftCurrencyEnum>Trait Implementations
Sourceimpl Clone for CraftCurrencyList
impl Clone for CraftCurrencyList
Sourcefn clone(&self) -> CraftCurrencyList
fn clone(&self) -> CraftCurrencyList
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CraftCurrencyList
impl Debug for CraftCurrencyList
Sourceimpl<'de> Deserialize<'de> for CraftCurrencyList
impl<'de> Deserialize<'de> for CraftCurrencyList
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for CraftCurrencyList
impl Display for CraftCurrencyList
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for CraftCurrencyListwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for CraftCurrencyListwhere
Self: Clone,
Sourceimpl Hash for CraftCurrencyList
impl Hash for CraftCurrencyList
Sourceimpl<'py> IntoPyObject<'py> for CraftCurrencyList
impl<'py> IntoPyObject<'py> for CraftCurrencyList
Sourcetype Target = CraftCurrencyList
type Target = CraftCurrencyList
The Python output type
Sourcetype Output = Bound<'py, <CraftCurrencyList as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <CraftCurrencyList as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for CraftCurrencyList
impl PartialEq for CraftCurrencyList
Sourceimpl PyClass for CraftCurrencyList
impl PyClass for CraftCurrencyList
Sourceimpl PyClassImpl for CraftCurrencyList
impl PyClassImpl for CraftCurrencyList
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<CraftCurrencyList>
type ThreadChecker = SendablePyClass<CraftCurrencyList>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn weaklist_offset() -> Option<Py_ssize_t>
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
Sourceimpl PyStubType for CraftCurrencyList
impl PyStubType for CraftCurrencyList
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
Sourcefn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for CraftCurrencyList
impl PyTypeInfo for CraftCurrencyList
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
Sourceimpl Serialize for CraftCurrencyList
impl Serialize for CraftCurrencyList
impl DerefToPyAny for CraftCurrencyList
impl Eq for CraftCurrencyList
impl StructuralPartialEq for CraftCurrencyList