pub struct ItemSnapshotHelper {
pub target_proximity: u8,
pub prefix_count: u8,
pub suffix_count: u8,
pub blocked_modgroups: THashSet<String>,
pub homogenized_mods: THashSet<u8>,
pub unwanted_affixes: THashSet<AffixSpecifier>,
pub is_desecrated: bool,
pub has_desecrated_target: Option<AffixSpecifier>,
pub marked_by_abyssal_lord: Option<AffixSpecifier>,
pub has_essences_target: THashSet<AffixSpecifier>,
}Fields
target_proximity: u8prefix_count: u8suffix_count: u8blocked_modgroups: THashSet<String>homogenized_mods: THashSet<u8>unwanted_affixes: THashSet<AffixSpecifier>is_desecrated: boolhas_desecrated_target: Option<AffixSpecifier>marked_by_abyssal_lord: Option<AffixSpecifier>has_essences_target: THashSet<AffixSpecifier>Trait Implementations
Sourceimpl Clone for ItemSnapshotHelper
impl Clone for ItemSnapshotHelper
Sourcefn clone(&self) -> ItemSnapshotHelper
fn clone(&self) -> ItemSnapshotHelper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ItemSnapshotHelper
impl Debug for ItemSnapshotHelper
Sourceimpl<'de> Deserialize<'de> for ItemSnapshotHelper
impl<'de> Deserialize<'de> for ItemSnapshotHelper
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ItemSnapshotHelper
impl Display for ItemSnapshotHelper
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for ItemSnapshotHelperwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for ItemSnapshotHelperwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for ItemSnapshotHelper
impl<'py> IntoPyObject<'py> for ItemSnapshotHelper
Sourcetype Target = ItemSnapshotHelper
type Target = ItemSnapshotHelper
The Python output type
Sourcetype Output = Bound<'py, <ItemSnapshotHelper as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <ItemSnapshotHelper as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for ItemSnapshotHelper
impl PyClass for ItemSnapshotHelper
Sourceimpl PyClassImpl for ItemSnapshotHelper
impl PyClassImpl for ItemSnapshotHelper
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<ItemSnapshotHelper>
type ThreadChecker = SendablePyClass<ItemSnapshotHelper>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn weaklist_offset() -> Option<Py_ssize_t>
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
Sourceimpl PyStubType for ItemSnapshotHelper
impl PyStubType for ItemSnapshotHelper
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
Sourcefn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for ItemSnapshotHelper
impl PyTypeInfo for ItemSnapshotHelper
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
Sourceimpl Serialize for ItemSnapshotHelper
impl Serialize for ItemSnapshotHelper
impl DerefToPyAny for ItemSnapshotHelper