pub struct EssenceDefinition {
pub name_essence: String,
pub base_tier_table: THashMap<BaseItemId, THashMap<AffixId, EssenceTierLevelMeta>>,
pub corrupt: bool,
}Fields
name_essence: Stringbase_tier_table: THashMap<BaseItemId, THashMap<AffixId, EssenceTierLevelMeta>>corrupt: boolTrait Implementations
Sourceimpl Clone for EssenceDefinition
impl Clone for EssenceDefinition
Sourcefn clone(&self) -> EssenceDefinition
fn clone(&self) -> EssenceDefinition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EssenceDefinition
impl Debug for EssenceDefinition
Sourceimpl<'de> Deserialize<'de> for EssenceDefinition
impl<'de> Deserialize<'de> for EssenceDefinition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for EssenceDefinition
impl Display for EssenceDefinition
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for EssenceDefinitionwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for EssenceDefinitionwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for EssenceDefinition
impl<'py> IntoPyObject<'py> for EssenceDefinition
Sourcetype Target = EssenceDefinition
type Target = EssenceDefinition
The Python output type
Sourcetype Output = Bound<'py, <EssenceDefinition as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <EssenceDefinition as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for EssenceDefinition
impl PartialEq for EssenceDefinition
Sourceimpl PyClass for EssenceDefinition
impl PyClass for EssenceDefinition
Sourceimpl PyClassImpl for EssenceDefinition
impl PyClassImpl for EssenceDefinition
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<EssenceDefinition>
type ThreadChecker = SendablePyClass<EssenceDefinition>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn weaklist_offset() -> Option<Py_ssize_t>
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
Sourceimpl PyStubType for EssenceDefinition
impl PyStubType for EssenceDefinition
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
Sourcefn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for EssenceDefinition
impl PyTypeInfo for EssenceDefinition
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
Sourceimpl Serialize for EssenceDefinition
impl Serialize for EssenceDefinition
impl DerefToPyAny for EssenceDefinition
impl Eq for EssenceDefinition
impl StructuralPartialEq for EssenceDefinition