pub struct EssenceTierLevelMeta {
pub id: String,
pub min_item_level: ItemLevel,
}Fields
id: Stringmin_item_level: ItemLevelTrait Implementations
Sourceimpl Clone for EssenceTierLevelMeta
impl Clone for EssenceTierLevelMeta
Sourcefn clone(&self) -> EssenceTierLevelMeta
fn clone(&self) -> EssenceTierLevelMeta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EssenceTierLevelMeta
impl Debug for EssenceTierLevelMeta
Sourceimpl<'de> Deserialize<'de> for EssenceTierLevelMeta
impl<'de> Deserialize<'de> for EssenceTierLevelMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for EssenceTierLevelMeta
impl Display for EssenceTierLevelMeta
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for EssenceTierLevelMetawhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for EssenceTierLevelMetawhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for EssenceTierLevelMeta
impl<'py> IntoPyObject<'py> for EssenceTierLevelMeta
Sourcetype Target = EssenceTierLevelMeta
type Target = EssenceTierLevelMeta
The Python output type
Sourcetype Output = Bound<'py, <EssenceTierLevelMeta as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <EssenceTierLevelMeta as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for EssenceTierLevelMeta
impl PartialEq for EssenceTierLevelMeta
Sourceimpl PyClass for EssenceTierLevelMeta
impl PyClass for EssenceTierLevelMeta
Sourceimpl PyClassImpl for EssenceTierLevelMeta
impl PyClassImpl for EssenceTierLevelMeta
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<EssenceTierLevelMeta>
type ThreadChecker = SendablePyClass<EssenceTierLevelMeta>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn weaklist_offset() -> Option<Py_ssize_t>
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
Sourceimpl PyStubType for EssenceTierLevelMeta
impl PyStubType for EssenceTierLevelMeta
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
Sourcefn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for EssenceTierLevelMeta
impl PyTypeInfo for EssenceTierLevelMeta
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
Sourceimpl Serialize for EssenceTierLevelMeta
impl Serialize for EssenceTierLevelMeta
impl DerefToPyAny for EssenceTierLevelMeta
impl Eq for EssenceTierLevelMeta
impl StructuralPartialEq for EssenceTierLevelMeta